@@ -1,8 +1,13 @@
-/***             analog 5.32             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
- *** stated otherwise. Distribution, usage and modification of this program is
- *** subject to the conditions of the Licence which you should have received
- *** with it. This program comes with no warranty, expressed or implied.   ***/
+/***             analog 6.0             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2004 except as
+ *** stated otherwise.
+ ***
+ *** This program is free software. You can redistribute it and/or modify it
+ *** under the terms of version 2 of the GNU General Public License, which you
+ *** should have received with it.
+ ***
+ *** This program is distributed in the hope that it will be useful, but
+ *** without any warranty, expressed or implied.   ***/
 
 /*** anlghea2.h: second header file ***/
 
@@ -68,9 +73,10 @@
 #define DNSBADHOURS (336)
 /* After how many hours to retry failed lookups. 336 = two weeks. */
 
-#define DNSTIMEOUT (5)
+#define DNSTIMEOUT (0)
 /* How many seconds to wait for the DNS server to reply before giving up. This
-   is only used on some platforms. */
+   is only used on some platforms. It is set to 0 by default, which means off,
+   because it breaks DNS lookups on many platforms. */
 #endif
 
 #define DIRSUFFIX "index.html"
@@ -399,17 +405,18 @@
    and the start of the statistics. Use "none" for none. */
 
 #define FOOTERFILE "none"
-/* And one placed at the bottom of the page */
+/* And one placed at the bottom of the page. */
 
-#define OUTPUT (HTML)
-/* Default output type: HTML, PLAIN, ASCII, COMPUTER or CACHE */
+#define OUTPUT (XHTML)
+/* Default output type: HTML, XHTML, PLAIN, ASCII, LATEX, COMPUTER or
+   OUT_NONE. */
 
 #ifndef LANGUAGE
 #define LANGUAGE (ENGLISH)
 /* Default language for the output page:
-   ARMENIAN, BULGARIAN, BULGARIAN_MIK, CATALAN, TRAD_CHINESE (Big5), CZECH,
-   CZECH_1250, DANISH, DUTCH, ENGLISH, US_ENGLISH, FINNISH, FRENCH, GERMAN,
-   HUNGARIAN, INDONESIAN, ITALIAN,
+   ARMENIAN, BASQUE, BULGARIAN, BULGARIAN_MIK, CATALAN, SIMP_CHINESE (GB2312),
+   TRAD_CHINESE (Big5), CZECH, CZECH_1250, DANISH, DUTCH, ENGLISH, US_ENGLISH,
+   FINNISH, FRENCH, GERMAN, HUNGARIAN, INDONESIAN, ITALIAN,
    JAPANESE_EUC, JAPANESE_JIS, JAPANESE_SJIS, JAPANESE_UTF,
    KOREAN, LATVIAN, NORWEGIAN (Bokmal), NYNORSK, POLISH, PORTUGUESE,
    BR_PORTUGUESE, RUSSIAN, RUSSIAN_1251, SERBIAN, SLOVAK, SLOVAK_1250,
@@ -418,8 +425,7 @@
    The following languages were available for previous versions of analog, but
    have not yet been translated for version 5. As they are translated, they
    will be added to the analog home page:
-   BOSNIAN, SIMP_CHINESE (GB2312), CROATIAN, GREEK, ICELANDIC, LITHUANIAN,
-   ROMANIAN and SLOVAK. */
+   BOSNIAN, CROATIAN, GREEK, ICELANDIC, LITHUANIAN, ROMANIAN and SLOVAK. */
 #endif
 
 #define MARKCHAR '+'
@@ -428,7 +434,7 @@
 #define BARSTYLE 'b'
 /* The default bar style for the displays -- 'a' to 'h' */
 
-#define PNGIMAGES (FALSE)
+#define PNGIMAGES (TRUE)
 /* Whether the graphics should be png's (TRUE) or gif's (FALSE). */
 
 #define HTMLPAGEWIDTH (65)
@@ -439,6 +445,10 @@
 #define MINGRAPHWIDTH (15)
 /* bar charts must be at least this many characters wide */
 
+#define CSSPREFIX ""
+/* A prefix to put in front of all CSS class names in XHTML mode.
+   Use "" for no prefix. */
+
 #define ERRLINELENGTH (78)
 #define STDERRWIDTH (ERRLINELENGTH)
 /* the maximum width for error and warning messages */
