@@ -1,8 +1,13 @@
-/***             analog 5.32             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
- *** stated otherwise. Distribution, usage and modification of this program is
- *** subject to the conditions of the Licence which you should have received
- *** with it. This program comes with no warranty, expressed or implied.   ***/
+/***             analog 6.0             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2004 except as
+ *** stated otherwise.
+ ***
+ *** This program is free software. You can redistribute it and/or modify it
+ *** under the terms of version 2 of the GNU General Public License, which you
+ *** should have received with it.
+ ***
+ *** This program is distributed in the hope that it will be useful, but
+ *** without any warranty, expressed or implied.   ***/
 
 /*** anlghea3.h: third header file ***/
 
@@ -14,7 +19,7 @@
 
 /*** OS specific things ***/
 
-#define VNUMBER "5.32"    /* the version number of this program */
+#define VNUMBER "6.0"    /* the version number of this program */
 
 #undef VERSION /* If no OS set, compilation will fail by not knowing VERSION */
 
@@ -220,7 +225,7 @@ extern void Win32Cleanup(void);
 
 #if defined(EBCDIC) && !defined(OS390) && !defined(AS400) && !defined(BS2000)
 /* Seems to be a not-yet-supported platform. */
-#error Unsupported EBCDIC platform. Please port Analog and contribute your changes back to <analog-author@lists.isite.net>!
+#error Unsupported EBCDIC platform. Please port Analog and contribute your changes back to <analog-author@lists.meer.net>!
 /* You might also want to have a look at:
  *   - globals.c  (system dependent EBCDIC translation tables)
  *   - settings.c (identification string for your OS)
@@ -250,8 +255,14 @@ extern void Win32Cleanup(void);
 
 /*** system dependent header files ***/
 
+#ifndef LINE_PARSER
 #include "zlib/zlib.h"
+#include "unzip/unzip.h"
+#include "bzip2/bzlib.h"
+#endif
+
 #include "pcre/pcre.h"
+
 #include "libgd/gd.h"
 #include "libgd/gdfontf.h"
 #include "libgd/gdfonts.h"
@@ -584,13 +595,16 @@ enum {REQUESTS, REQUESTS7, PAGES, PAGES7, REDIR, REDIR7, FAIL, FAIL7, SUCCDATE,
 enum {REQUESTS2, REQUESTS72, PAGES2, PAGES72, DATE2, FIRSTD2, DATA2_NUMBER,
       DATACOLS_NUMBER};
 
+/* Type of logfile by compression */
+enum {LF_NOTOPENED, LF_NORMAL, LF_PIPE, LF_GZIP, LF_ZIP, LF_ZIPMEMBER, LF_BZ2};
+
 /* Data collected about total requests etc. in each logfile */
 enum {LOGDATA_UNWANTED, LOGDATA_UNKNOWN, LOGDATA_UNKNOWN7, LOGDATA_INFO,
       LOGDATA_INFO7, LOGDATA_SUCC, LOGDATA_SUCC7, LOGDATA_PAGES,
       LOGDATA_PAGES7, LOGDATA_REDIR, LOGDATA_REDIR7, LOGDATA_FAIL,
       LOGDATA_FAIL7, LOGDATA_CORRUPT, LOGDATA_NUMBER};
 
-/* Poss. columns: COL_TITLE must be first; see also configcols() in init2.c */
+/* Poss. columns: COL_TITLE must be first; see also colcodes[] in globals.c */
 enum {COL_TITLE, COL_REQS, COL_REQS7, COL_PAGES, COL_PAGES7, COL_BYTES,
       COL_BYTES7, COL_PREQS, COL_PREQS7, COL_PPAGES, COL_PPAGES7, COL_PBYTES,
       COL_PBYTES7, COL_DATE, COL_TIME, COL_FIRSTD, COL_FIRSTT, COL_INDEX,
@@ -599,15 +613,15 @@ enum {COL_TITLE, COL_REQS, COL_REQS7, COL_PAGES, COL_PAGES7, COL_BYTES,
 /* Levels of DNS lookup. Keep in order. */
 enum {DNS_NONE, DNS_READ, DNS_LOOKUP, DNS_WRITE};
 
-/* Output types: start with HTML then PLAIN */
-enum {HTML, PLAIN, ASCII, LATEX, COMPUTER, OUT_NONE};
+/* Output types: start with XHTML then PLAIN */
+enum {XHTML, PLAIN, ASCII, HTML, LATEX, COMPUTER, XML, OUT_NONE};
 
 /* days of the week */
 enum {SUNDAY, MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY};
 
 /* languages; see also country in globals.c */
-enum {ARMENIAN, /*BOSNIAN,*/ BULGARIAN, BULGARIAN_MIK, CATALAN,
-      /*SIMP_CHINESE,*/ TRAD_CHINESE, /*CROATIAN,*/ CZECH, CZECH_1250, DANISH,
+enum {ARMENIAN, BASQUE, /*BOSNIAN,*/ BULGARIAN, BULGARIAN_MIK, CATALAN,
+      SIMP_CHINESE, TRAD_CHINESE, /*CROATIAN,*/ CZECH, CZECH_1250, DANISH,
       DUTCH, ENGLISH, US_ENGLISH, FINNISH, FRENCH, GERMAN, /*GREEK,*/
       HUNGARIAN, /*ICELANDIC,*/ INDONESIAN, ITALIAN, JAPANESE_EUC,
       JAPANESE_JIS,
@@ -619,7 +633,7 @@ enum {ARMENIAN, /*BOSNIAN,*/ BULGARIAN, BULGARIAN_MIK, CATALAN,
 
 /* source of data passed to htmlputs(): see comments there. These represent
    roughly increasing levels of security. */
-enum {TRUSTED, FROM_CFG, UNTRUSTED, IN_HREF};
+enum {AS_IS, TRUSTED, FROM_CFG, UNTRUSTED, IN_HREF};
 
 /* lngstrs; charset_ must be first */
 enum {charset_, weekbeg_, year_, quarteryr_, month_, day_, days_, hr_, minute_,
@@ -717,7 +731,6 @@ typedef struct hashindex *(*mergefnp)(struct hashindex *, struct hashindex *,
 				      unsigned long, unsigned long, choice);
 typedef void (*conffnp)(void *, char *, char *, char *, int);
 typedef choice (*inputfnp)(struct logfile *lf, void *, char);
-typedef size_t (*htmlstrlenp)(char *, choice);
 
 /*** structs */
 
@@ -791,8 +804,9 @@ typedef struct inputformatlist {
 
 typedef struct logfile {
   char *name;
-  FILE *file;
-  gzFile gzfile;
+  void *file;
+  void *file2;  /* bzip2 needs the (FILE *) and the (BZFILE *) */
+  choice type;
   Inputformatlist *format;
   timecode_t from, to;
   unsigned long data[LOGDATA_NUMBER];
@@ -800,7 +814,6 @@ typedef struct logfile {
   char *prefix;
   size_t prefixlen;
   int pvpos, tz;
-  logical ispipe;
   struct logfile *next;
 } Logfile;
 
@@ -892,7 +905,89 @@ typedef struct {
   char *file;
 } Lang;
 
+struct outchoices;
+
+/* The actual outputters are defined in globals.c */
 typedef struct {
+  unsigned int (*pagewidth)(struct outchoices *);
+  void (*cgihead)(FILE *, struct outchoices *);
+  void (*stylehead)(FILE *, struct outchoices *);
+  void (*pagetitle)(FILE *, struct outchoices *);
+  void (*timings)(FILE *, struct outchoices *, Dateman *);
+  void (*closehead)(FILE *, struct outchoices *);
+  void (*pagebotstart)(FILE *, struct outchoices *);
+  void (*credit)(FILE *, struct outchoices *);
+  void (*runtime)(FILE *, struct outchoices *, long);
+  void (*pagefoot)(FILE *, struct outchoices *);
+  void (*stylefoot)(FILE *, struct outchoices *);
+  void (*reporttitle)(FILE *, struct outchoices *, choice);
+  void (*reportfooter)(FILE *, struct outchoices *, choice);
+  void (*reportdesc)(FILE *, struct outchoices *, choice);
+  void (*reportspan)(FILE *, struct outchoices *, choice, timecode_t,
+		     timecode_t);
+  void (*gensumhead)(FILE *, struct outchoices *);
+  void (*gensumfoot)(FILE *, struct outchoices *);
+  void (*gensumline)(FILE *, struct outchoices *, int, unsigned long,
+		     unsigned long, logical);
+  void (*gensumlineb)(FILE *, struct outchoices *, int, double, double,
+		      logical);
+  void (*lastseven)(FILE *, struct outchoices *, timecode_t);
+  void (*prestart)(FILE *, struct outchoices *);
+  void (*preend)(FILE *, struct outchoices *);
+  void (*hrule)(FILE *, struct outchoices *);
+  char *(*endash)(void);
+  void (*putch)(FILE *, char);
+  size_t (*strlength)(const char *);
+  logical (*allowmonth)(void);
+  void (*calcwidths)(struct outchoices *, choice, unsigned int [],
+		     unsigned int *, unsigned int *, double *, unsigned long,
+		     unsigned long, unsigned long, unsigned long, double,
+		     double, unsigned long);
+  void (*declareunit)(FILE *, struct outchoices *, char, double, unsigned int);
+  void (*colheadstart)(FILE *, struct outchoices *, choice);
+  void (*colheadcol)(FILE *, struct outchoices *, choice, choice, unsigned int,
+		     char *, logical);
+  void (*colheadend)(FILE *, struct outchoices *, choice);
+  void (*colheadustart)(FILE *, struct outchoices *, choice);
+  void (*colheadunderline)(FILE *, struct outchoices *, choice,
+			   choice, unsigned int, char *);
+  void (*colheaduend)(FILE *, struct outchoices *, choice);
+  void (*rowstart)(FILE *, struct outchoices *, choice, choice *, int, char *,
+		   char *, char *);
+  void (*levelcell)(FILE *, struct outchoices *, choice, int);
+  void (*namecell)(FILE *, struct outchoices *, choice, char *, choice,
+		   unsigned int, logical, logical, logical, Alias *, Include *,
+		   logical, unsigned int, char *);
+  void (*ulcell)(FILE *, struct outchoices *, choice, choice, unsigned long,
+		 unsigned int);
+  void (*strcell)(FILE *, struct outchoices *, choice, choice, char *,
+		  unsigned int);
+  void (*bytescell)(FILE *, struct outchoices *, choice, choice, double,
+		    double, unsigned int);
+  void (*pccell)(FILE *, struct outchoices *, choice, choice, double, double,
+		 unsigned int);
+  void (*indexcell)(FILE *, struct outchoices *, choice, choice, long,
+		    unsigned int);
+  void (*rowend)(FILE *, struct outchoices *, choice);
+  void (*blankline)(FILE *, struct outchoices *, choice *);
+  void (*barchart)(FILE *, struct outchoices *, int, char);
+  void (*busyprintf)(FILE *, struct outchoices *, choice, char *,
+		     unsigned long, unsigned long, double, datecode_t,
+		     unsigned int, unsigned int, datecode_t, unsigned int,
+		     unsigned int, char);
+  void (*notlistedstr)(FILE *, struct outchoices *, choice, unsigned long);
+  void (*whatincluded)(FILE *, struct outchoices *, choice, unsigned long,
+		       Dateman *);
+  void (*whatinchead)(FILE *, struct outchoices *);
+  void (*whatincfoot)(FILE *, struct outchoices *);
+  void (*whatincprintstr)(FILE *, struct outchoices *, char *);
+  void (*printdouble)(FILE *, struct outchoices *, double);
+  void (*includefile)(FILE *, struct outchoices *, char *, char);
+  unsigned int (*riscosfiletype)(void);
+} Outputter;
+
+typedef struct outchoices {
+  Outputter *outputter;
   char *outfile, *cacheoutfile;
   char *domainsfile, *descfile, *headerfile, *footerfile;
   choice outstyle, gotos;
@@ -911,14 +1006,14 @@ typedef struct {
   Lang lang;
   char *dayname[7], *monthname[12], **lngstr, *descstr[REP_NUMBER];
   size_t daylen, plaindaylen, monthlen, plainmonthlen, ampmlen, plainampmlen;
-  char *hostname, *hosturl, *logo, *imagedir, *stylesheet;
-  char *chartdir, *localchartdir;
+  char *hostname, *hosturl, *logo, *logourl, *imagedir;
+  char *stylesheet,*cssprefix, *chartdir, *localchartdir;
   char markchar;
   logical norobots;
   logical rawbytes;
   unsigned int bytesdp;
   choice weekbeginson;
-  unsigned int plainpagewidth, htmlpagewidth, latexpagewidth, pagewidth;
+  unsigned int plainpagewidth, htmlpagewidth, latexpagewidth;
   unsigned int mingraphwidth;
   char sepchar, repsepchar, decpt, barstyle;
   char *compsep, *gensumlines;
@@ -1078,14 +1173,7 @@ typedef struct {
 #define CLREPTOGGLE(n) CLTOGGLE(op->outopts.repq[n])
 #define CLOUTSTYLE CLTOGGLE
 #define CLGOTOS CLTOGGLE
-/* these happen to work because PLAIN == TRUE == ON and HTML == FALSE == OFF */
-/* abbreviations for output */
-#define PRESTART() if (od->outstyle == HTML) fputs("<pre><tt>", outf);\
-  else if (od->outstyle == ASCII) fputc('\n', outf);\
-  else if (od->outstyle == LATEX) fputs("\\smallskip\n\\begin{obeylines}\n",\
-                                        outf);
-#define PREEND() if (od->outstyle == HTML) fputs("</tt></pre>\n", outf);\
-  else if (od->outstyle == LATEX) fputs("\\end{obeylines}\n", outf);
+/* these work because PLAIN == TRUE == ON and XHTML == FALSE == OFF */
 /* an abbreviation for arrays with size GENREP_NUMBER */
 #define G(r) ((r) - FIRST_GENREP)
 /* magicno as macro not fn. for speed: x is unsigned long to contain answer,
