@@ -1,8 +1,13 @@
-/***             analog 5.32             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
- *** stated otherwise. Distribution, usage and modification of this program is
- *** subject to the conditions of the Licence which you should have received
- *** with it. This program comes with no warranty, expressed or implied.   ***/
+/***             analog 6.0             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2004 except as
+ *** stated otherwise.
+ ***
+ *** This program is free software. You can redistribute it and/or modify it
+ *** under the terms of version 2 of the GNU General Public License, which you
+ *** should have received with it.
+ ***
+ *** This program is distributed in the hope that it will be useful, but
+ *** without any warranty, expressed or implied.   ***/
 
 /*** settings.c; report variable settings */
 
@@ -504,7 +509,7 @@ void report_outopts(Outchoices *od) {
 	else { /* REP_SIZE || REP_PROCTIME */
 	  report_cols(od->cols[j]);
 #ifndef NOGRAPHICS
-	  if (od->outstyle == HTML)
+	  if (od->outstyle == HTML || od->outstyle == XHTML)
 	    report_chart(od->chartby[G(j)]);
 	  numcharts += (od->chartby[G(j)] != CHART_NONE);
 #endif
@@ -524,7 +529,7 @@ void report_outopts(Outchoices *od) {
     check_file(od->lang.file);
     printf("Domains file is %s\n", od->domainsfile);
     check_file(od->domainsfile);
-    if (od->outstyle == HTML)
+    if (od->outstyle == HTML || od->outstyle == XHTML)
       printf("Go To lines are %s\n",
 	     (od->gotos == TRUE)?"on":((od->gotos == FALSE)?"off":
 				       "on at top and bottom only"));
@@ -547,6 +552,17 @@ void report_outopts(Outchoices *od) {
       else
 	printf("Style sheet is %s\n", od->stylesheet);
     }
+    else if (od->outstyle == XHTML) {
+      printf("XHTML\n");
+      if (strcaseeq(od->stylesheet, "none"))
+	printf("Default (inline) style sheet\n");
+      else
+	printf("Style sheet is %s\n", od->stylesheet);
+      if (strcaseeq(od->stylesheet, "none"))
+	printf("No CSS prefix\n");
+      else
+	printf("CSS prefix is %s\n", od->cssprefix);
+    }
     else if (od->outstyle == ASCII)
       printf("ASCII\n");
     else if (od->outstyle == PLAIN)
@@ -572,7 +588,7 @@ void report_outopts(Outchoices *od) {
       check_file(od->footerfile);
     }
     printf("Host name for title is %s\n", od->hostname);
-    if (od->outstyle == HTML) {
+    if (od->outstyle == HTML || od->outstyle == XHTML) {
       if (strcaseeq(od->hosturl, "none"))
 	printf("Host name unlinked\n");
       else
@@ -584,6 +600,12 @@ void report_outopts(Outchoices *od) {
 	if (STREQ(od->logo, "analogo"))
 	  printf(".%s", od->pngimages?"png":"gif");
 	putchar('\n');
+	if (od->outstyle == XHTML) {
+	  if (strcaseeq(od->logourl, "none"))
+	    printf("Logo unlinked\n");
+	  else
+	    printf("Logo linked to %s\n", od->logourl);
+	}
       }
       printf("URL of image directory is %s\n", od->imagedir);
       printf("Using %s images\n", od->pngimages?"PNG":"GIF");
@@ -614,7 +636,7 @@ void report_outopts(Outchoices *od) {
       report_sep(od->sepchar, "thousands separator");
       report_sep(od->repsepchar, "thousands separator in tables");
       report_sep(od->decpt, "decimal point");
-      printf("The page width is %d\n", od->pagewidth);
+      printf("The page width is %d\n", od->outputter->pagewidth(od));
       printf("The minimum graph width is %d\n", od->mingraphwidth);
     }
     printf("Weeks begin on %s\n", englongdays[od->weekbeginson]);
@@ -662,7 +684,7 @@ void report_genrep(Outchoices *od, choice j) {
     report_floor(&(od->subfloor[G(j)]), TRUE);
   }
 #ifndef NOGRAPHICS
-  if (od->outstyle == HTML)
+  if (od->outstyle == HTML || od->outstyle == XHTML)
     report_chart(od->chartby[G(j)]);
 #endif
   report_want(od->wanthead[G(j)], "in the report", "    ");
@@ -820,7 +842,7 @@ void report_floor(Floor *floor, logical sub) {
 	  printf("%s in the last 7 days\n", (temp == 1)?"byte":"bytes");
       }
       else {  /* floor->qual != '\0' */
-	doublemprintf(stdout, ASCII, 0, floor->min, '.');
+	plain_printdouble(stdout, NULL, floor->min);
 	if (floor->qual == '%') {
 	  if (floor->floorby == REQUESTS)
 	    printf("%% of the requests\n");
