@@ -1,8 +1,13 @@
-/***             analog 5.32             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
- *** stated otherwise. Distribution, usage and modification of this program is
- *** subject to the conditions of the Licence which you should have received
- *** with it. This program comes with no warranty, expressed or implied.   ***/
+/***             analog 6.0             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2004 except as
+ *** stated otherwise.
+ ***
+ *** This program is free software. You can redistribute it and/or modify it
+ *** under the terms of version 2 of the GNU General Public License, which you
+ *** should have received with it.
+ ***
+ *** This program is distributed in the hope that it will be useful, but
+ *** without any warranty, expressed or implied.   ***/
 
 #include "anlghea3.h"
 
@@ -766,6 +771,8 @@ void Bnextname(char **name, char **nameend, char *whole, void *arg) {
 	((*name = strstr(whole, "Konqueror")) != NULL && (len = 9)) ||
 	((*name = strstr(whole, "Galeon")) != NULL && (len = 6)) ||
 	((*name = strstr(whole, "Phoenix")) != NULL && (len = 7)) ||
+	((*name = strstr(whole, "Firebird")) != NULL && (len = 8)) ||
+	((*name = strstr(whole, "Firefox")) != NULL && (len = 7)) ||
 	((*name = strstr(whole, "Chimera")) != NULL && (len = 7)) ||
 	((*name = strstr(whole, "Camino")) != NULL && (len = 6)) ||
 	((*name = strstr(whole, "Safari")) != NULL && (len = 6)) ||
@@ -859,6 +866,8 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
 	    *name = "Windows:Windows 2000";
 	  else if (*(c + 1) == '.' && (*(c + 2) == '1'))
 	    *name = "Windows:Windows XP";
+	  else if (*(c + 1) == '.' && (*(c + 2) == '2'))
+	    *name = "Windows:Windows Server 2003";
 	  else
 	    *name = "Windows:Unknown Windows";
 	}
@@ -922,6 +931,11 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
       *name = "RISC OS";
     else if (strstr(whole, "Amiga") != NULL)
       *name = "Amiga";
+    else if (strstr(whole, "Symbian") != NULL)
+      *name = "Symbian OS";
+    else if (strstr(whole, "PalmOS") != NULL ||
+	     strstr(whole, "PalmSource") != NULL)
+      *name = "Palm OS";
     else if (strstr(whole, "Atari") != NULL)
       *name = "Atari";
     else
