@@ -1,8 +1,13 @@
-/***             analog 5.32             http://www.analog.cx/             ***/
-/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2003 except as
- *** stated otherwise. Distribution, usage and modification of this program is
- *** subject to the conditions of the Licence which you should have received
- *** with it. This program comes with no warranty, expressed or implied.   ***/
+/***             analog 6.0             http://www.analog.cx/             ***/
+/*** This program is copyright (c) Stephen R. E. Turner 1995 - 2004 except as
+ *** stated otherwise.
+ ***
+ *** This program is free software. You can redistribute it and/or modify it
+ *** under the terms of version 2 of the GNU General Public License, which you
+ *** should have received with it.
+ ***
+ *** This program is distributed in the hope that it will be useful, but
+ *** without any warranty, expressed or implied.   ***/
 
 /*** utils.c; lots of little functions to do odd little things ***/
 
@@ -100,7 +105,7 @@ char *strtoupper(char *n) {
   return(n);
 }
 
-void strtolowerx(char *n) {  /* only used in next 2 fns. */
+void strtolowerx(char *n) { /* lower-case filename: only used in next 3 fns. */
   for ( ; *n != '\0' && *n != '?'; n++)
     *n = TOLOWER(*n);
 }
@@ -139,6 +144,11 @@ void tolowerinc(Include *ip) {
   }
 }
 
+void tolowerse(Strpairlist *sp) {  /* for (internal) search engines */
+  for ( ; sp != NULL; TO_NEXT(sp))
+    strtolowerx(sp->name);
+}
+
 void reversealias(Alias **head) {
   /* aliases are first collated in reverse order */
   Alias *ap, *lastap = NULL, *nextap;
@@ -335,14 +345,20 @@ double arraymaxd(double *x, unsigned int size) {
   return(y);
 }
 
-size_t arraymaxlen(char **s, unsigned int size, choice outstyle) {
-  extern htmlstrlenp htmlstrlen;
-
+size_t arraymaxlen(char **s, unsigned int size, Outchoices *od) {
   unsigned int i;
   size_t y = 0;
 
+  size_t (*strlenp)(const char *);
+
+  if (od == NULL)
+    strlenp = &strlen;
+  else
+    strlenp = od->outputter->strlength;
+
   for (i = 0; i < size; i++)
-    y = MAX(htmlstrlen(s[i], outstyle), y);
+    y = MAX(strlenp(s[i]), y);
+
   return(y);
 }
 
