@@ -1,19 +1,14 @@
-/*************************************
-*      zlib compression library      *
-**************************************/
+/* adler32.c -- compute the Adler-32 checksum of a data stream
+ * Copyright (C) 1995-2002 Mark Adler
+ * For conditions of distribution and use, see copyright notice in zlib.h 
+ */
 
-/* This file contains code from Jean-loup Gailly and Mark Adler's zlib
-   library, heavily modified by Stephen Turner for use in analog. See the file
-   LICENSE in this directory for details. */
-
-/* (C) 1995-2002 Jean-loup Gailly and Mark Adler */
-
-#ifndef NOGRAPHICS
-#ifndef HAVE_GD
+#ifndef HAVE_ZLIB
 #include "zlib.h"
 
-#define BASE 65521L
+#define BASE 65521L /* largest prime smaller than 65536 */
 #define NMAX 5552
+/* NMAX is the largest n such that 255n(n+1)/2 + (n+1)(BASE-1) <= 2^32-1 */
 
 #define DO1(buf,i)  {s1 += buf[i]; s2 += s1;}
 #define DO2(buf,i)  DO1(buf,i); DO1(buf,i+1);
@@ -21,6 +16,7 @@
 #define DO8(buf,i)  DO4(buf,i); DO4(buf,i+4);
 #define DO16(buf)   DO8(buf,0); DO8(buf,8);
 
+/* ========================================================================= */
 uLong ZEXPORT adler32(adler, buf, len)
     uLong adler;
     const Bytef *buf;
@@ -49,5 +45,5 @@ uLong ZEXPORT adler32(adler, buf, len)
     }
     return (s2 << 16) | s1;
 }
-#endif  /* HAVE_GD */
-#endif  /* NOGRAPHICS */
+
+#endif /* HAVE_ZLIB */
