@@ -1,41 +1,60 @@
-/*************************************
-*      zlib compression library      *
-**************************************/
+/* zutil.c -- target dependent utility functions for the compression library
+ * Copyright (C) 1995-2002 Jean-loup Gailly.
+ * For conditions of distribution and use, see copyright notice in zlib.h 
+ */
 
-/* This file contains code from Jean-loup Gailly and Mark Adler's zlib
-   library, heavily modified by Stephen Turner for use in analog. See the file
-   LICENSE in this directory for details. */
-
-/* (C) 1995-2002 Jean-loup Gailly and Mark Adler */
-
-#ifndef NOGRAPHICS
-#ifndef HAVE_GD
+#ifndef HAVE_ZLIB
 #include "zutil.h"
 
-struct internal_state      {int dummy;};
+struct internal_state      {int dummy;}; /* for buggy compilers */
 
 #ifndef STDC
 extern void exit OF((int));
 #endif
 
 const char *z_errmsg[10] = {
-"need dictionary",
-"stream end",
-"",
-"file error",
-"stream error",
-"data error",
-"insufficient memory",
-"buffer error",
-"incompatible version",
+"need dictionary",     /* Z_NEED_DICT       2  */
+"stream end",          /* Z_STREAM_END      1  */
+"",                    /* Z_OK              0  */
+"file error",          /* Z_ERRNO         (-1) */
+"stream error",        /* Z_STREAM_ERROR  (-2) */
+"data error",          /* Z_DATA_ERROR    (-3) */
+"insufficient memory", /* Z_MEM_ERROR     (-4) */
+"buffer error",        /* Z_BUF_ERROR     (-5) */
+"incompatible version",/* Z_VERSION_ERROR (-6) */
 ""};
 
+
+const char * ZEXPORT zlibVersion()
+{
+    return ZLIB_VERSION;
+}
+
+#ifdef DEBUG
+
+#  ifndef verbose
+#    define verbose 0
+#  endif
+int z_verbose = verbose;
+
+void z_error (m)
+    char *m;
+{
+    fprintf(stderr, "%s\n", m);
+    exit(1);
+}
+#endif
+
+/* exported to allow conversion of error code to string for compress() and
+ * uncompress()
+ */
 const char * ZEXPORT zError(err)
     int err;
 {
     return ERR_MSG(err);
 }
 
+
 #ifndef HAVE_MEMCPY
 
 void zmemcpy(dest, source, len)
@@ -45,7 +64,7 @@ void zmemcpy(dest, source, len)
 {
     if (len == 0) return;
     do {
-        *dest++ = *source++;
+        *dest++ = *source++; /* ??? to be unrolled */
     } while (--len != 0);
 }
 
@@ -68,15 +87,26 @@ void zmemzero(dest, len)
 {
     if (len == 0) return;
     do {
-        *dest++ = 0;
+        *dest++ = 0;  /* ??? to be unrolled */
     } while (--len != 0);
 }
 #endif
 
 #ifdef __TURBOC__
 #if (defined( __BORLANDC__) || !defined(SMALL_MEDIUM)) && !defined(__32BIT__)
+/* Small and medium model in Turbo C are for now limited to near allocation
+ * with reduced MAX_WBITS and MAX_MEM_LEVEL
+ */
 #  define MY_ZCALLOC
+
+/* Turbo C malloc() does not allow dynamic allocation of 64K bytes
+ * and farmalloc(64K) returns a pointer with an offset of 8, so we
+ * must fix the pointer. Warning: the pointer must be put back to its
+ * original form in order to free it, use zcfree().
+ */
+
 #define MAX_PTR 10
+/* 10*64K = 640K */
 
 local int next_ptr = 0;
 
@@ -86,11 +116,21 @@ typedef struct ptr_table_s {
 } ptr_table;
 
 local ptr_table table[MAX_PTR];
+/* This table is used to remember the original form of pointers
+ * to large buffers (64K). Such pointers are normalized with a zero offset.
+ * Since MSDOS is not a preemptive multitasking OS, this table is not
+ * protected from concurrent access. This hack doesn't work anyway on
+ * a protected system like OS/2. Use Microsoft C instead.
+ */
 
 voidpf zcalloc (voidpf opaque, unsigned items, unsigned size)
 {
-    voidpf buf = opaque;
+    voidpf buf = opaque; /* just to make some compilers happy */
     ulg bsize = (ulg)items*size;
+
+    /* If we allocate less than 65520 bytes, we assume that farmalloc
+     * will return a usable pointer which doesn't have to be normalized.
+     */
     if (bsize < 65520L) {
         buf = farmalloc(bsize);
         if (*(ush*)&buf != 0) return buf;
@@ -100,7 +140,7 @@ voidpf zcalloc (voidpf opaque, unsigned items, unsigned size)
     if (buf == NULL || next_ptr >= MAX_PTR) return NULL;
     table[next_ptr].org_ptr = buf;
 
-
+    /* Normalize the pointer to seg:0 */
     *((ush*)&buf+1) += ((ush)((uch*)buf-0) + 15) >> 4;
     *(ush*)&buf = 0;
     table[next_ptr++].new_ptr = buf;
@@ -110,11 +150,11 @@ voidpf zcalloc (voidpf opaque, unsigned items, unsigned size)
 void  zcfree (voidpf opaque, voidpf ptr)
 {
     int n;
-    if (*(ush*)&ptr != 0) {
+    if (*(ush*)&ptr != 0) { /* object < 64K */
         farfree(ptr);
         return;
     }
-
+    /* Find the original pointer */
     for (n = 0; n < next_ptr; n++) {
         if (ptr != table[n].new_ptr) continue;
 
@@ -125,12 +165,13 @@ void  zcfree (voidpf opaque, voidpf ptr)
         next_ptr--;
         return;
     }
-    ptr = opaque;
+    ptr = opaque; /* just to make some compilers happy */
     Assert(0, "zcfree: ptr not found");
 }
 #endif
 #endif /* __TURBOC__ */
 
+
 #if defined(M_I86) && !defined(__32BIT__)
 /* Microsoft C in 16-bit mode */
 
@@ -143,18 +184,19 @@ void  zcfree (voidpf opaque, voidpf ptr)
 
 voidpf zcalloc (voidpf opaque, unsigned items, unsigned size)
 {
-    if (opaque) opaque = 0;
+    if (opaque) opaque = 0; /* to make compiler happy */
     return _halloc((long)items, size);
 }
 
 void  zcfree (voidpf opaque, voidpf ptr)
 {
-    if (opaque) opaque = 0;
+    if (opaque) opaque = 0; /* to make compiler happy */
     _hfree(ptr);
 }
 
 #endif /* MSC */
 
+
 #ifndef MY_ZCALLOC /* Any system without a special alloc function */
 
 #ifndef STDC
@@ -167,7 +209,7 @@ voidpf zcalloc (opaque, items, size)
     unsigned items;
     unsigned size;
 {
-    if (opaque) items += size - size;
+    if (opaque) items += size - size; /* make compiler happy */
     return (voidpf)calloc(items, size);
 }
 
@@ -176,10 +218,9 @@ void  zcfree (opaque, ptr)
     voidpf ptr;
 {
     free(ptr);
-    if (opaque) return;
+    if (opaque) return; /* make compiler happy */
 }
 
-#endif  /* MY_ZCALLOC */
+#endif /* MY_ZCALLOC */
 
-#endif  /* HAVE_GD */
-#endif  /* NOGRAPHICS */
+#endif /* HAVE_ZLIB */
