@@ -1,14 +1,13 @@
-/*************************************
-*      zlib compression library      *
-**************************************/
+/* zutil.h -- internal interface and configuration of the compression library
+ * Copyright (C) 1995-2002 Jean-loup Gailly.
+ * For conditions of distribution and use, see copyright notice in zlib.h
+ */
 
-/* This file contains code from Jean-loup Gailly and Mark Adler's zlib
-   library, heavily modified by Stephen Turner for use in analog. See the file
-   LICENSE in this directory for details. */
+/* WARNING: this file should *not* be used by applications. It is
+   part of the implementation of the compression library and is
+   subject to change. Applications should only use zlib.h.
+ */
 
-/* (C) 1995-2002 Jean-loup Gailly and Mark Adler */
-
-#ifndef NOGRAPHICS
 #ifndef _Z_UTIL_H
 #define _Z_UTIL_H
 
@@ -28,6 +27,7 @@
 #ifndef local
 #  define local static
 #endif
+/* compile with -Dlocal if your debugger can't find static symbols */
 
 typedef unsigned char  uch;
 typedef uch FAR uchf;
@@ -35,36 +35,47 @@ typedef unsigned short ush;
 typedef ush FAR ushf;
 typedef unsigned long  ulg;
 
-extern const char *z_errmsg[10];
+extern const char *z_errmsg[10]; /* indexed by 2-zlib_error */
+/* (size given to avoid silly warnings with Visual C++) */
 
 #define ERR_MSG(err) z_errmsg[Z_NEED_DICT-(err)]
 
 #define ERR_RETURN(strm,err) \
   return (strm->msg = (char*)ERR_MSG(err), (err))
+/* To be used only when the state is known to be valid */
+
+        /* common constants */
 
 #ifndef DEF_WBITS
 #  define DEF_WBITS MAX_WBITS
 #endif
+/* default windowBits for decompression. MAX_WBITS is for compression only */
 
 #if MAX_MEM_LEVEL >= 8
 #  define DEF_MEM_LEVEL 8
 #else
 #  define DEF_MEM_LEVEL  MAX_MEM_LEVEL
 #endif
+/* default memLevel */
 
 #define STORED_BLOCK 0
 #define STATIC_TREES 1
 #define DYN_TREES    2
+/* The three kinds of block type */
 
 #define MIN_MATCH  3
 #define MAX_MATCH  258
+/* The minimum and maximum match lengths */
 
-#define PRESET_DICT 0x20
+#define PRESET_DICT 0x20 /* preset dictionary flag in zlib header */
+
+        /* target dependencies */
 
 #ifdef MSDOS
 #  define OS_CODE  0x00
 #  if defined(__TURBOC__) || defined(__BORLANDC__)
 #    if(__STDC__ == 1) && (defined(__LARGE__) || defined(__COMPACT__))
+       /* Allow compilation with ANSI keywords only enabled */
        void _Cdecl farfree( void *block );
        void *_Cdecl farmalloc( unsigned long nbytes );
 #    else
@@ -124,6 +135,9 @@ extern const char *z_errmsg[10];
 #  define fdopen(fd,type)  _fdopen(fd,type)
 #endif
 
+
+        /* Common defaults */
+
 #ifndef OS_CODE
 #  define OS_CODE  0x03  /* assume Unix */
 #endif
@@ -132,6 +146,8 @@ extern const char *z_errmsg[10];
 #  define F_OPEN(name, mode) fopen((name), (mode))
 #endif
 
+         /* functions */
+
 #ifdef HAVE_STRERROR
    extern char *strerror OF((int));
 #  define zstrerror(errnum) strerror(errnum)
@@ -143,6 +159,10 @@ extern const char *z_errmsg[10];
 #  define NO_MEMCPY
 #endif
 #if defined(SMALL_MEDIUM) && !defined(_MSC_VER) && !defined(__SC__)
+ /* Use our own functions for small and medium model with MSC <= 5.0.
+  * You may have to use the same strategy for Borland C (untested).
+  * The __SC__ check is for Symantec.
+  */
 #  define NO_MEMCPY
 #endif
 #if defined(STDC) && !defined(HAVE_MEMCPY) && !defined(NO_MEMCPY)
@@ -164,12 +184,26 @@ extern const char *z_errmsg[10];
    extern void zmemzero OF((Bytef* dest, uInt len));
 #endif
 
+/* Diagnostic functions */
+#ifdef DEBUG
+#  include <stdio.h>
+   extern int z_verbose;
+   extern void z_error    OF((char *m));
+#  define Assert(cond,msg) {if(!(cond)) z_error(msg);}
+#  define Trace(x) {if (z_verbose>=0) fprintf x ;}
+#  define Tracev(x) {if (z_verbose>0) fprintf x ;}
+#  define Tracevv(x) {if (z_verbose>1) fprintf x ;}
+#  define Tracec(c,x) {if (z_verbose>0 && (c)) fprintf x ;}
+#  define Tracecv(c,x) {if (z_verbose>1 && (c)) fprintf x ;}
+#else
 #  define Assert(cond,msg)
 #  define Trace(x)
 #  define Tracev(x)
 #  define Tracevv(x)
 #  define Tracec(c,x)
 #  define Tracecv(c,x)
+#endif
+
 
 typedef uLong (ZEXPORT *check_func) OF((uLong check, const Bytef *buf,
 				       uInt len));
@@ -182,4 +216,3 @@ void   zcfree  OF((voidpf opaque, voidpf ptr));
 #define TRY_FREE(s, p) {if (p) ZFREE(s, p);}
 
 #endif /* _Z_UTIL_H */
-#endif /* NOGRAPHICS */
